@@ -87,6 +87,7 @@
 #include "MagickCore/string-private.h"
 #include "MagickCore/thread_.h"
 #include "MagickCore/thread-private.h"
+#include "MagickCore/timer-private.h"
 #include "MagickCore/type-private.h"
 #include "MagickCore/token.h"
 #include "MagickCore/utility.h"
@@ -1468,13 +1469,32 @@ static SignalHandler *RegisterMagickSignalHandler(int signal_number)
   return(handler);
 }
 
+static void SetClientNameAndPath(const char *path)
+{
+  char
+    execution_path[MagickPathExtent],
+    filename[MagickPathExtent];
+
+#if defined(MAGICKCORE_WINDOWS_SUPPORT)
+  if ((path != (const char *) NULL) && (IsPathAccessible(path) != MagickFalse))
+#else
+  if ((path != (const char *) NULL) && (*path == *DirectorySeparator) &&
+      (IsPathAccessible(path) != MagickFalse))
+#endif
+    (void) CopyMagickString(execution_path,path,MagickPathExtent);
+  else
+    (void) GetExecutionPath(execution_path,MagickPathExtent);
+  GetPathComponent(execution_path,TailPath,filename);
+  (void) SetClientName(filename);
+  GetPathComponent(execution_path,HeadPath,execution_path);
+  (void) SetClientPath(execution_path);
+}
+
 MagickExport void MagickCoreGenesis(const char *path,
   const MagickBooleanType establish_signal_handlers)
 {
   char
-    *events,
-    execution_path[MagickPathExtent],
-    filename[MagickPathExtent];
+    *events;
 
   /*
     Initialize the Magick environment.
@@ -1493,6 +1513,7 @@ MagickExport void MagickCoreGenesis(const char *path,
     }
   (void) SemaphoreComponentGenesis();
   (void) ExceptionComponentGenesis();
+  SetClientNameAndPath(path);
   (void) LogComponentGenesis();
   (void) LocaleComponentGenesis();
   (void) RandomComponentGenesis();
@@ -1505,22 +1526,6 @@ MagickExport void MagickCoreGenesis(const char *path,
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
   NTWindowsGenesis();
 #endif
-  /*
-    Set client name and execution path.
-  */
-#if defined(MAGICKCORE_WINDOWS_SUPPORT)
-  if ((path != (const char *) NULL) && (IsPathAccessible(path) != MagickFalse))
-#else
-  if ((path != (const char *) NULL) && (*path == *DirectorySeparator) &&
-      (IsPathAccessible(path) != MagickFalse))
-#endif
-    (void) CopyMagickString(execution_path,path,MagickPathExtent);
-  else
-    (void) GetExecutionPath(execution_path,MagickPathExtent);
-  GetPathComponent(execution_path,TailPath,filename);
-  (void) SetClientName(filename);
-  GetPathComponent(execution_path,HeadPath,execution_path);
-  (void) SetClientPath(execution_path);
   if (establish_signal_handlers != MagickFalse)
     {
       /*
