@@ -738,6 +738,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->colorspace=(ColorspaceType) colorspace;
                     break;
                   }
+                if (LocaleCompare(keyword,"columns") == 0)
+                  {
+                    image->columns=StringToUnsignedLong(options);
+                    break;
+                  }
                 if (LocaleCompare(keyword,"compression") == 0)
                   {
                     ssize_t
@@ -750,11 +755,6 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->compression=(CompressionType) compression;
                     break;
                   }
-                if (LocaleCompare(keyword,"columns") == 0)
-                  {
-                    image->columns=StringToUnsignedLong(options);
-                    break;
-                  }
                 (void) SetImageProperty(image,keyword,options,exception);
                 break;
               }
@@ -843,8 +843,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 if (LocaleCompare(keyword,"id") == 0)
                   {
                     if (*id != '\0')
-                      ThrowMIFFException(CorruptImageError,
-                        "ImproperImageHeader");
+                      {
+                        options=DestroyString(options);
+                        ThrowMIFFException(CorruptImageError,
+                          "ImproperImageHeader");
+                      }
                     (void) CopyMagickString(id,options,MagickPathExtent);
                     break;
                   }
